complex_doc.pdf

## Metadata

Title | complex_doc.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\complex_doc.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230325085300+00'00'
PDF Metadata: modDate | D:20230325085300+00'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h2 :: A Test Document
3. h4 :: A Second Title
4. h6 :: List Title

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 219.25999450683594
y1 |  | 94.96131134033203
y0 |  | 74.92131042480469
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 172.85000610351562
y1 |  | 124.82185363769531
y0 |  | 108.86184692382812
x0 |  | 72.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 520.7880249023438
y1 |  | 207.62771606445312
y0 |  | 126.62771606445312
x0 |  | 72.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 522.3400268554688
y1 |  | 290.6977233886719
y0 |  | 223.46774291992188
x0 |  | 72.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 512.1839599609375
y1 |  | 387.417724609375
y0 |  | 306.4176940917969
x0 |  | 72.02400207519531

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 282.1700134277344
y1 |  | 591.7077026367188
y0 |  | 414.0777282714844
x0 |  | 72.02400207519531

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 122.05999755859375
y1 |  | 619.9745483398438
y0 |  | 607.9745483398438
x0 |  | 72.02400207519531

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 280.3699951171875
y1 |  | 762.2113037109375
y0 |  | 635.732177734375
x0 |  | 90.02400207519531

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 496.8999938964844
y1 |  | 614.7999877929688
y0 |  | 426.3499755859375
x0 |  | 327.3999938964844

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 523.137939453125
y1 |  | 748.6876831054688
y0 |  | 626.2677001953125
x0 |  | 315.42999267578125

## A Test Document

#### A Second Title

malesuada justo. Vivamus sagittis at tortor vitae sodales. Donec sit amet egestas nulla. Cras eget auctor libero. Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu eros, finibus eget elementum ut, ultricies nec metus. Ut eget sagittis turpis, a dignissim orci. Nunc vestibulum dui sed commodo congue. Praesent ultrices mattis tortor.

Aliquam diam neque, eleifend ac mauris sit amet, molestie finibus odio. Phasellus sagittis est sem, non aliquam mi porta ut. Ut sodales lectus ut ultrices tristique. Nullam nec pulvinar ex. Quisque fermentum nisl quis est volutpat dictum. Curabitur aliquam ex a sapien faucibus tempor. Etiam accumsan tempus turpis a aliquet. In nec eros nunc. Phasellus sit amet varius erat. Mauris dictum egestas sodales.

Aliquam pellentesque metus in risus dapibus suscipit. Quisque ut ultricies orci. Praesent sit amet faucibus ante. Proin vel fringilla lectus. Vivamus at interdum sem. Aliquam pellentesque metus in risus dapibus suscipit. Quisque ut ultricies orci. Praesent sit amet faucibus ante. Proin vel fringilla lectus. Vivamus at interdum sem. Aliquam pellentesque metus in risus dapibus suscipit. Quisque ut ultricies orci. Praesent sit amet faucibus ante. Proin vel fringilla lectus. Vivamus at interdum sem.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

###### List Title

- Suspendisse commodo condimentum dolor, eu consectetur

- dui posuere sed. Curabitur eros

- sem, venenatis consectetur ultricies in, vehicula sodales felis.

- Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae

- sodales. Donec sit amet egestas

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. vestibulum efficitur et vel ante.

Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu.

## A Test Document

#### A Second Title

malesuada justo. Vivamus sagittis at tortor vitae sodales. Donec sit amet egestas nulla. Cras eget auctor libero. Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu eros, finibus eget elementum ut, ultricies nec metus. Ut eget sagittis turpis, a dignissim orci. Nunc vestibulum dui sed commodo congue. Praesent ultrices mattis tortor.

Aliquam diam neque, eleifend ac mauris sit amet, molestie finibus odio. Phasellus sagittis est sem, non aliquam mi porta ut. Ut sodales lectus ut ultrices tristique. Nullam nec pulvinar ex. Quisque fermentum nisl quis est volutpat dictum. Curabitur aliquam ex a sapien faucibus tempor. Etiam accumsan tempus turpis a aliquet. In nec eros nunc. Phasellus sit amet varius erat. Mauris dictum egestas sodales.

Aliquam pellentesque metus in risus dapibus suscipit. Quisque ut ultricies orci. Praesent sit amet faucibus ante. Proin vel fringilla lectus. Vivamus at interdum sem. Aliquam pellentesque metus in risus dapibus suscipit. Quisque ut ultricies orci. Praesent sit amet faucibus ante. Proin vel fringilla lectus. Vivamus at interdum sem. Aliquam pellentesque metus in risus dapibus suscipit. Quisque ut ultricies orci. Praesent sit amet faucibus ante. Proin vel fringilla lectus. Vivamus at interdum sem.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

###### List Title

- Suspendisse commodo condimentum dolor, eu consectetur

- dui posuere sed. Curabitur eros

- sem, venenatis consectetur ultricies in, vehicula sodales felis.

- Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae

- sodales. Donec sit amet egestas

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. vestibulum efficitur et vel ante.

Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu.

Parent File Contents